pub enum Calhs {
NoActiveHsTrimRequest = 0,
HsTrimRequestPending = 1,
}Expand description
High Speed Mode Trim Request
Value on reset: 0
Variants
NoActiveHsTrimRequest = 0
0: No request for high speed mode trim has been made
HsTrimRequestPending = 1
1: Request for high speed mode trim has been made