CalhsR

Type Alias CalhsR 

pub type CalhsR = BitReader<Calhs>;
Field CALHS reader - High Speed Mode Trim Request

Aliased Type

pub struct CalhsR { /* private fields */ }

Implementations

Source

impl CalhsR

pub const fn variant(&self) -> Calhs

Get enumerated values variant

pub fn is_no_active_hs_trim_request(&self) -> bool

No request for high speed mode trim has been made

pub fn is_hs_trim_request_pending(&self) -> bool

Request for high speed mode trim has been made