CalhsW

Type Alias CalhsW 

pub type CalhsW<'a, REG> = BitWriter<'a, REG, Calhs>;
Field CALHS writer - High Speed Mode Trim Request

Aliased Type

pub struct CalhsW<'a, REG> { /* private fields */ }

Implementations

Source

impl<'a, REG> CalhsW<'a, REG>
where REG: Writable + RegisterSpec,

pub fn no_active_hs_trim_request(self) -> &'a mut W<REG>

No request for high speed mode trim has been made

pub fn hs_trim_request_pending(self) -> &'a mut W<REG>

Request for high speed mode trim has been made