#[repr(u8)]pub enum Tot {
Notrnps = 0,
BtsTrnps = 1,
BytsBtsTrnps = 2,
BytsTrnps = 3,
}Expand description
Transpose Type for Write
Value on reset: 0
Variants
Notrnps = 0
0: No transposition
BtsTrnps = 1
1: Bits in bytes are transposed, but bytes are not transposed.
BytsBtsTrnps = 2
2: Both bits in bytes and bytes are transposed.
BytsTrnps = 3
3: Only bytes are transposed, no bits in a byte are transposed.