Rev

Enum Rev 

pub enum Rev {
    Rev0 = 0,
    Rev1 = 1,
}
Enable Reverse Direction Counting

Value on reset: 0

Variants



Rev0 = 0

0: Count normally and the position counter initialization uses upper/lower initialization register UINIT/LINIT



Rev1 = 1

1: Count in the reverse direction and the position counter initialization uses upper/lower modulus register UMOD/LMOD