LdokR

Type Alias LdokR 

pub type LdokR = BitReader<Ldok>;
Field LDOK reader - Load Okay

Aliased Type

pub struct LdokR { /* private fields */ }

Implementations

Source

impl LdokR

pub const fn variant(&self) -> Ldok

Get enumerated values variant

pub fn is_ldok0(&self) -> bool

No loading action taken. Users can write new values to buffered registers (writing into outer-set of these buffered registers)

pub fn is_ldok1(&self) -> bool

Outer-set values are ready to be loaded into inner-set and take effect. The loading time point depends on CTRL2[LDMOD].