RevR

Type Alias RevR 

pub type RevR = BitReader<Rev>;
Field REV reader - Enable Reverse Direction Counting

Aliased Type

pub struct RevR { /* private fields */ }

Implementations

Source

impl RevR

pub const fn variant(&self) -> Rev

Get enumerated values variant

pub fn is_rev0(&self) -> bool

Count normally and the position counter initialization uses upper/lower initialization register UINIT/LINIT

pub fn is_rev1(&self) -> bool

Count in the reverse direction and the position counter initialization uses upper/lower modulus register UMOD/LMOD