RevW

Type Alias RevW 

pub type RevW<'a, REG> = BitWriter<'a, REG, Rev>;
Field REV writer - Enable Reverse Direction Counting

Aliased Type

pub struct RevW<'a, REG> { /* private fields */ }

Implementations

Source

impl<'a, REG> RevW<'a, REG>
where REG: Writable + RegisterSpec,

pub fn rev0(self) -> &'a mut W<REG>

Count normally and the position counter initialization uses upper/lower initialization register UINIT/LINIT

pub fn rev1(self) -> &'a mut W<REG>

Count in the reverse direction and the position counter initialization uses upper/lower modulus register UMOD/LMOD