pub enum Emip {
Emip0 = 0,
Emip1 = 1,
}Expand description
Enables/disables the position counter to be initialized by Index Event Edge Mark
Value on reset: 0
Variants
Emip0 = 0
0: disables the position counter to be initialized by Index Event Edge Mark
Emip1 = 1
1: enables the position counter to be initialized by Index Event Edge Mark.