Ldmod

Enum Ldmod 

pub enum Ldmod {
    Ldmod0 = 0,
    Ldmod1 = 1,
}
Buffered Register Load (Update) Mode Select

Value on reset: 0

Variants



Ldmod0 = 0

0: Buffered registers are loaded and take effect immediately upon CTRL[LDOK] is set.



Ldmod1 = 1

1: Buffered registers are loaded and take effect at the next roll-over or roll-under if CTRL[LDOK] is set.