EmipR

Type Alias EmipR 

pub type EmipR = BitReader<Emip>;
Field EMIP reader - Enables/disables the position counter to be initialized by Index Event Edge Mark

Aliased Type

pub struct EmipR { /* private fields */ }

Implementations

Source

impl EmipR

pub const fn variant(&self) -> Emip

Get enumerated values variant

pub fn is_emip0(&self) -> bool

disables the position counter to be initialized by Index Event Edge Mark

pub fn is_emip1(&self) -> bool

enables the position counter to be initialized by Index Event Edge Mark.