pub type EmipW<'a, REG> = BitWriter<'a, REG, Emip>;
Field EMIP writer - Enables/disables the position counter to be initialized by Index Event Edge Mark
EMIP
pub struct EmipW<'a, REG> { /* private fields */ }
disables the position counter to be initialized by Index Event Edge Mark
enables the position counter to be initialized by Index Event Edge Mark.