LdmodW

Type Alias LdmodW 

pub type LdmodW<'a, REG> = BitWriter<'a, REG, Ldmod>;
Field LDMOD writer - Buffered Register Load (Update) Mode Select

Aliased Type

pub struct LdmodW<'a, REG> { /* private fields */ }

Implementations

Source

impl<'a, REG> LdmodW<'a, REG>
where REG: Writable + RegisterSpec,

pub fn ldmod0(self) -> &'a mut W<REG>

Buffered registers are loaded and take effect immediately upon CTRL[LDOK] is set.

pub fn ldmod1(self) -> &'a mut W<REG>

Buffered registers are loaded and take effect at the next roll-over or roll-under if CTRL[LDOK] is set.