OutctlW

Type Alias OutctlW 

pub type OutctlW<'a, REG> = BitWriter<'a, REG, Outctl>;
Field OUTCTL writer - Output Control

Aliased Type

pub struct OutctlW<'a, REG> { /* private fields */ }

Implementations

Source

impl<'a, REG> OutctlW<'a, REG>
where REG: Writable + RegisterSpec,

pub fn outctl0(self) -> &'a mut W<REG>

POS_MATCH[x](x range is 0-3) is asserted when the Position Counter is equal to according compare value (UCOMPx/LCOMPx)(x range is 0-3), and de-asserted when the Position Counter not equal to the compare value (UCOMPx/LCOMPx)(x range is 0-3)

pub fn outctl1(self) -> &'a mut W<REG>

All POS_MATCH[x](x range is 0-3) are asserted a pulse, when the UPOS, LPOS, REV, or POSD registers are read