#[repr(u8)]pub enum InitSel {
PwmX = 0,
MasterReload = 1,
MasterSync = 2,
ExtSync = 3,
}Expand description
Initialization Control Select
Value on reset: 0
Variants
PwmX = 0
0: Local sync (PWM_X) causes initialization.
MasterReload = 1
1: Master reload from submodule 0 causes initialization. This setting should not be used in submodule 0 as it forces the INIT signal to logic 0. The submodule counter will only re-initialize when a master reload occurs.
MasterSync = 2
2: Master sync from submodule 0 causes initialization. This setting should not be used in submodule 0 as it forces the INIT signal to logic 0.
ExtSync = 3
3: EXT_SYNC causes initialization.