pub enum Ldmod {
NextPwmReload = 0,
MtctrlLdokSet = 1,
}Expand description
Load Mode Select
Value on reset: 0
Variants
NextPwmReload = 0
0: Buffered registers of this submodule are loaded and take effect at the next PWM reload if MCTRL[LDOK] is set.
MtctrlLdokSet = 1
1: Buffered registers of this submodule are loaded and take effect immediately upon MCTRL[LDOK] being set. In this case, it is not necessary to set CTRL[FULL] or CTRL[HALF].