Fdfd

Enum Fdfd 

pub enum Fdfd {
    Fdfd0 = 0,
    Fdfd1 = 1,
}
Force Double Bit Fault Detect

Value on reset: 0

Variants



Fdfd0 = 0

0: FSTAT[DFDIF] sets only if a double bit fault is detected during a valid flash read access from the platform flash controller



Fdfd1 = 1

1: FSTAT[DFDIF] sets during any valid flash read access from the platform flash controller. An interrupt request is generated if the DFDIE bit is set.