FdfdR

Type Alias FdfdR 

pub type FdfdR = BitReader<Fdfd>;
Field FDFD reader - Force Double Bit Fault Detect

Aliased Type

pub struct FdfdR { /* private fields */ }

Implementations

Source

impl FdfdR

pub const fn variant(&self) -> Fdfd

Get enumerated values variant

pub fn is_fdfd0(&self) -> bool

FSTAT[DFDIF] sets only if a double bit fault is detected during a valid flash read access from the platform flash controller

pub fn is_fdfd1(&self) -> bool

FSTAT[DFDIF] sets during any valid flash read access from the platform flash controller. An interrupt request is generated if the DFDIE bit is set.