LockR

Type Alias LockR 

pub type LockR = BitReader<Lock>;
Field LOCK reader - This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.

Aliased Type

pub struct LockR { /* private fields */ }

Implementations

Source

impl LockR

pub const fn variant(&self) -> Lock

Get enumerated values variant

pub fn is_lock_0(&self) -> bool

This register is not locked and can be altered.

pub fn is_lock_1(&self) -> bool

This register is locked and cannot be altered until a system reset.