LockW

Type Alias LockW 

pub type LockW<'a, REG> = BitWriter<'a, REG, Lock>;
Field LOCK writer - This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.

Aliased Type

pub struct LockW<'a, REG> { /* private fields */ }

Implementations

Source

impl<'a, REG> LockW<'a, REG>
where REG: Writable + RegisterSpec,

pub fn lock_0(self) -> &'a mut W<REG>

This register is not locked and can be altered.

pub fn lock_1(self) -> &'a mut W<REG>

This register is locked and cannot be altered until a system reset.