R

Type Alias R 

pub type R = R<ProtlvlSpec>;
Register PROTLVL reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn priv_(&self) -> PrivR

Bit 0 - Control privileged access of EIM, ERM, Flexcan, MBC, SCG.

pub fn locknsmpu(&self) -> LocknsmpuR

Bit 16 - Control write access to Nonsecure MPU memory regions.

pub fn lock(&self) -> LockR

Bit 31 - This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.