W

Type Alias W 

pub type W = W<ProtlvlSpec>;
Register PROTLVL writer

Aliased Type

pub struct W { /* private fields */ }

Implementations

Source

impl W

pub fn priv_(&mut self) -> PrivW<'_, ProtlvlSpec>

Bit 0 - Control privileged access of EIM, ERM, Flexcan, MBC, SCG.

pub fn locknsmpu(&mut self) -> LocknsmpuW<'_, ProtlvlSpec>

Bit 16 - Control write access to Nonsecure MPU memory regions.

pub fn lock(&mut self) -> LockW<'_, ProtlvlSpec>

Bit 31 - This 1-bit field provides a mechanism to limit writes to the this register to protect its contents. Once set, this bit remains asserted until a system reset.