pub type CalhsW<'a, REG> = BitWriter<'a, REG, Calhs>;Expand description
Field CALHS writer - High Speed Mode Trim Request
Aliased Type
pub struct CalhsW<'a, REG> { /* private fields */ }Implementations
Sourceimpl<'a, REG> CalhsW<'a, REG>where
REG: Writable + RegisterSpec,
impl<'a, REG> CalhsW<'a, REG>where
REG: Writable + RegisterSpec,
Sourcepub fn no_active_hs_trim_request(self) -> &'a mut W<REG>
pub fn no_active_hs_trim_request(self) -> &'a mut W<REG>
No request for high speed mode trim has been made
Sourcepub fn hs_trim_request_pending(self) -> &'a mut W<REG>
pub fn hs_trim_request_pending(self) -> &'a mut W<REG>
Request for high speed mode trim has been made