Hne

Enum Hne 

pub enum Hne {
    Hne0 = 0,
    Hne1 = 1,
}
Use Negative Edge of HOME/ENABLE Input

Value on reset: 0

Variants



Hne0 = 0

0: When CTRL[OPMODE] = 0,use HOME positive edge to trigger initialization of position counters. When CTRL[OPMODE] = 1,use ENABLE high level to enable POS/POSD/WDG/REV counters



Hne1 = 1

1: When CTRL[OPMODE] = 0,use HOME negative edge to trigger initialization of position counters. When CTRL[OPMODE] = 1,use ENABLE low level to enable POS/POSD/WDG/REV counters