pub enum Ldok {
Ldok0 = 0,
Ldok1 = 1,
}Expand description
Load Okay
Value on reset: 0
Variants
Ldok0 = 0
0: No loading action taken. Users can write new values to buffered registers (writing into outer-set of these buffered registers)
Ldok1 = 1
1: Outer-set values are ready to be loaded into inner-set and take effect. The loading time point depends on CTRL2[LDMOD].