pub type EmipR = BitReader<Emip>;
Field EMIP reader - Enables/disables the position counter to be initialized by Index Event Edge Mark
EMIP
pub struct EmipR { /* private fields */ }
Get enumerated values variant
disables the position counter to be initialized by Index Event Edge Mark
enables the position counter to be initialized by Index Event Edge Mark.