EmipW

Type Alias EmipW 

pub type EmipW<'a, REG> = BitWriter<'a, REG, Emip>;
Field EMIP writer - Enables/disables the position counter to be initialized by Index Event Edge Mark

Aliased Type

pub struct EmipW<'a, REG> { /* private fields */ }

Implementations

Source

impl<'a, REG> EmipW<'a, REG>
where REG: Writable + RegisterSpec,

pub fn emip0(self) -> &'a mut W<REG>

disables the position counter to be initialized by Index Event Edge Mark

pub fn emip1(self) -> &'a mut W<REG>

enables the position counter to be initialized by Index Event Edge Mark.