pub type OutctlR = BitReader<Outctl>;Expand description
Field OUTCTL reader - Output Control
Aliased Type
pub struct OutctlR { /* private fields */ }Implementations
Sourceimpl OutctlR
impl OutctlR
Sourcepub fn is_outctl0(&self) -> bool
pub fn is_outctl0(&self) -> bool
POS_MATCH[x](x range is 0-3) is asserted when the Position Counter is equal to according compare value (UCOMPx/LCOMPx)(x range is 0-3), and de-asserted when the Position Counter not equal to the compare value (UCOMPx/LCOMPx)(x range is 0-3)
Sourcepub fn is_outctl1(&self) -> bool
pub fn is_outctl1(&self) -> bool
All POS_MATCH[x](x range is 0-3) are asserted a pulse, when the UPOS, LPOS, REV, or POSD registers are read