pub enum RamaCgOverride {
Disable = 0,
Enable = 1,
}Expand description
RAMA bank clock gating control, only avaiable when RAMA_ECC_ENABLE = 0.
Value on reset: 0
Variants
Disable = 0
0: Memory bank clock is gated automatically if no access more than 16 clock cycles
Enable = 1
1: Auto clock gating feature is disabled